Merge "Fix issue #3122240: Expose xlarge in GB." into gingerbread
diff --git a/api/current.xml b/api/current.xml
index 11b5104..8aba74a 100644
--- a/api/current.xml
+++ b/api/current.xml
@@ -18536,17 +18536,6 @@
  visibility="public"
 >
 </field>
-<field name="IMPORTANCE_HEAVY_WEIGHT"
- type="int"
- transient="false"
- volatile="false"
- value="170"
- static="true"
- final="true"
- deprecated="not deprecated"
- visibility="public"
->
-</field>
 <field name="IMPORTANCE_PERCEPTIBLE"
  type="int"
  transient="false"
@@ -49296,6 +49285,17 @@
  visibility="public"
 >
 </field>
+<field name="SCREENLAYOUT_SIZE_XLARGE"
+ type="int"
+ transient="false"
+ volatile="false"
+ value="4"
+ static="true"
+ final="true"
+ deprecated="not deprecated"
+ visibility="public"
+>
+</field>
 <field name="TOUCHSCREEN_FINGER"
  type="int"
  transient="false"
diff --git a/core/java/android/content/res/Configuration.java b/core/java/android/content/res/Configuration.java
index 5a3dd41..ef38236 100644
--- a/core/java/android/content/res/Configuration.java
+++ b/core/java/android/content/res/Configuration.java
@@ -62,7 +62,6 @@
     public static final int SCREENLAYOUT_SIZE_SMALL = 0x01;
     public static final int SCREENLAYOUT_SIZE_NORMAL = 0x02;
     public static final int SCREENLAYOUT_SIZE_LARGE = 0x03;
-    /** @hide */
     public static final int SCREENLAYOUT_SIZE_XLARGE = 0x04;
     
     public static final int SCREENLAYOUT_LONG_MASK = 0x30;
diff --git a/core/java/android/os/Build.java b/core/java/android/os/Build.java
index 08c1402..edd0bd3 100644
--- a/core/java/android/os/Build.java
+++ b/core/java/android/os/Build.java
@@ -188,15 +188,7 @@
         public static final int FROYO = 8;
         
         /**
-         * Next version of Android.
-         * 
-         * <p>Applications targeting this or a later release will get these
-         * new changes in behavior:</p>
-         * <ul>
-         * <li> The status bar is now dark.  Targeting this version allows
-         * the platform to perform performing compatibility on status bar
-         * graphics to ensure they look okay on a dark background.
-         * </ul>
+         * Newest version of Android, version 2.3.
          */
         public static final int GINGERBREAD = 9;
     }
diff --git a/services/java/com/android/server/am/ActivityManagerService.java b/services/java/com/android/server/am/ActivityManagerService.java
index aa2f784..6db4559 100644
--- a/services/java/com/android/server/am/ActivityManagerService.java
+++ b/services/java/com/android/server/am/ActivityManagerService.java
@@ -7051,7 +7051,7 @@
                     } else if (adj >= SECONDARY_SERVER_ADJ) {
                         currApp.importance = ActivityManager.RunningAppProcessInfo.IMPORTANCE_SERVICE;
                     } else if (adj >= HEAVY_WEIGHT_APP_ADJ) {
-                        currApp.importance = ActivityManager.RunningAppProcessInfo.IMPORTANCE_HEAVY_WEIGHT;
+                        currApp.importance = ActivityManager.RunningAppProcessInfo.IMPORTANCE_CANT_SAVE_STATE;
                     } else if (adj >= PERCEPTIBLE_APP_ADJ) {
                         currApp.importance = ActivityManager.RunningAppProcessInfo.IMPORTANCE_PERCEPTIBLE;
                     } else if (adj >= VISIBLE_APP_ADJ) {
diff --git a/core/java/android/app/ActivityManager.java b/core/java/android/app/ActivityManager.java
index 5ae8a1f..fe1e7d7 100644
--- a/core/java/android/app/ActivityManager.java
+++ b/core/java/android/app/ActivityManager.java
@@ -797,10 +797,12 @@
         public static final int IMPORTANCE_PERCEPTIBLE = 130;
         
         /**
          * Constant for {@link #importance}: this process is running a
          * heavy-weight application and thus should not be killed.
          */
-        public static final int IMPORTANCE_HEAVY_WEIGHT = 170;
+        public static final int IMPORTANCE_CANT_SAVE_STATE = 170;
         
         /**
          * Constant for {@link #importance}: this process is contains services
@@ -797,10 +797,12 @@
         
         /**
-         * Constant for {@link #importance}: this process is running a
-         * heavy-weight application and thus should not be killed.
+         * Constant for {@link #importance}: this process is running an
+         * application that can not save its state, and thus can't be killed
+         * while in the background.
+         * @hide
          */